@@ -14,7 +14,10 @@ class Redis(BaseModel):
     cache: Any = None
 
     def get_dsn(self):
-        return 'redis://{}:{}/{}'.format(self.host, self.port, self.db)
+        if self.username!=None and self.password!=None:
+            return 'redis://{}:{}@{}:{}/{}'.format(self.username, self.password, self.host, self.port, self.db)
+        else:
+            return 'redis://{}:{}/{}'.format(self.host, self.port, self.db)
 
     def connect(self) -> StrictRedis:
         return StrictRedis(host=self.host, port=self.port, username=self.username, password=self.password, db=self.db, decode_responses=True)
